@@ -1,9 +1,10 @@
 package net_sniff
 
 import (
-	"github.com/bettercap/bettercap/packets"
 	"net"
 
+	"github.com/bettercap/bettercap/v2/packets"
+
 	"github.com/google/gopacket"
 	"github.com/google/gopacket/layers"
 
