@@ -7,7 +7,7 @@ import (
 	"regexp"
 	"strings"
 
-	"github.com/bettercap/bettercap/core"
+	"github.com/bettercap/bettercap/v2/core"
 
 	"github.com/evilsocket/islazy/data"
 	"github.com/evilsocket/islazy/str"
