@@ -12,8 +12,8 @@ import (
 	"strings"
 	"time"
 
-	"github.com/bettercap/bettercap/core"
-	"github.com/bettercap/bettercap/network"
+	"github.com/bettercap/bettercap/v2/core"
+	"github.com/bettercap/bettercap/v2/network"
 
 	"github.com/bettercap/readline"
 	"github.com/evilsocket/islazy/str"
